insert_mouse_position

Function insert_mouse_position 

pub fn insert_mouse_position(
    In: In<(Option<Vec2>, Option<Vec2>)>,
    game: ResMut<'_, BonesGame>,
)
Bevy system that takes the mouse positions for the world and screen as input and inserts them into the BonesGame.