pub struct BonesGame(pub Game);Expand description
Bevy resource containing the [bones::Game]
Tuple Fields
0: GameImplementations
Methods from Deref<Target = Game>
pub fn install_plugin<P>(&mut self, plugin: P) -> &mut Gamewhere
P: GamePlugin,
pub fn install_plugin<P>(&mut self, plugin: P) -> &mut Gamewhere
P: GamePlugin,
Install a [GamePlugin].
Get the shared resource of a given type out of this [Game]s shared
resources if it exists.
Get the mutable shared resource of a given type out of this [Game]s
shared resources if it exists.
Get the shared resource of a given type out of this [Game]s shared
resources. Panics if the resource doesn’t exist.
Get the mutable shared resource of a given type out of this [Game]s
shared resources. Panics if it doesn’t exist.
Get the shared resource cell of a given type out of this [Game]s shared resources.
Initialize a resource that will be shared across game sessions using it’s Default value
if it is not already initialized, and borrow it for modification.
Insert a resource that will be shared across all game sessions.
Note: This resource will only be visible in sessions that have not already initialized or access a resource of the same type locally.