pub fn default_load_progress(asset_server: &AssetServer, ctx: &Context)Expand description
The system for displaying the default egui loading screen.
pub fn default_load_progress(asset_server: &AssetServer, ctx: &Context)The system for displaying the default egui loading screen.